# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-Path-Class
Version:	0.37
Release:	24.%{__distinit}%{__distvers}
Summary:	Cross-platform path specification manipulation
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Path-Class
Source0:	https://cpan.metacpan.org/authors/id/K/KW/KWILLIAMS/Path-Class-%{version}.tar.gz
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.30
# Module Runtime
BuildRequires:	perl(Carp)
BuildRequires:	perl(Cwd)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Copy)
BuildRequires:	perl(File::Path)
BuildRequires:	perl(File::Spec) >= 3.26
BuildRequires:	perl(File::stat)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Dir)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(overload)
BuildRequires:	perl(parent)
BuildRequires:	perl(Perl::OSType)
BuildRequires:	perl(Scalar::Util)
BuildRequires:	perl(strict)
# Test Suite
BuildRequires:	perl(Test)
BuildRequires:	perl(Test::More) >= 0.88
BuildRequires:	perl(warnings)
# Author Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(English)
BuildRequires:	perl(Test::Perl::Critic)
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(File::Copy)
Requires:	perl(Perl::OSType)

%description
Path::Class is a module for manipulation of file and directory specifications
(strings describing their locations, like '/home/ken/foo.txt' or
'C:\Windows\Foo.txt') in a cross-platform manner. It supports pretty much every
platform Perl runs on, including Unix, Windows, Mac, VMS, Epoc, Cygwin, OS/2,
and NetWare.

%prep
%setup -q -n Path-Class-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

# Remove files we don't want installed (only if we have old EU::MM)
# README.pod manified  prior to EU::MM 7.12 (F-25)
# README.pod installed prior to EU::MM 7.32 (F-28)
rm -vf %{buildroot}%{_mandir}/man3/Path::README.3*
rm -vf %{buildroot}%{perl_vendorlib}/Path/README.pod

%check
make test %{!?perl_bootstrap:AUTHOR_TESTING=1}

%files
%license LICENSE
%doc Changes README
%{perl_vendorlib}/Path/
%{_mandir}/man3/Path::Class.3*
%{_mandir}/man3/Path::Class::Dir.3*
%{_mandir}/man3/Path::Class::Entity.3*
%{_mandir}/man3/Path::Class::File.3*

%changelog
* Tue May  9 2023 Paul Howarth <paul@city-fan.org> - 0.37-24
- Use SPDX-format license tag
- Switch to ExtUtils::MakeMaker flow
- Use %%license unconditionally

* Mon Jun 29 2020 Paul Howarth <paul@city-fan.org> - 0.37-16
- Perl 5.32 rebuild

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.37-12
- Perl 5.30 rebuild

* Thu Apr 19 2018 Paul Howarth <paul@city-fan.org> - 0.37-6
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.88

* Mon Aug 15 2016 Paul Howarth <paul@city-fan.org> - 0.37-1
- Update to 0.37:
  - Doc update for contains/subsumes
  - Fix "contains" when $self is a relative path (GH#43)
  - Handle case where $other evaluates false
  - Add additional test cases for contains and subsumes
  - Test with Perl 5.24
- BR: perl-generators where available
- Update patch to support building with old versions of Test::More

* Wed Feb 17 2016 Paul Howarth <paul@city-fan.org> - 0.36-1
- Update to 0.36:
  - Use croak instead of die; use eval syntax instead of universal::isa (as
    perlcritic wishes)
  - Load File::Copy and Perl::OSType only when used (copy_to, move_to)
  - Always use canonpath on arguments to splitdir
  - Fix 'Operation "eq": no method found' error (CPAN RT#77259)
  - Add some fixes and tests for contains() with updir stuff (GH#43)
  - Fix Carp::Croak to Carp::croak
  - Fixed and improved Travis testing configuration
  - Fix Pod typos
  - Check all print calls in spew and explicitly call (and check) close
- Add patch to support building with old versions of Test::More

* Tue Sep 23 2014 Paul Howarth <paul@city-fan.org> - 0.35-1
- Update to 0.35:
  - Fixed a t/03-filesystem.t test error on Windows
- Classify buildreqs by usage

* Mon Sep  8 2014 Paul Howarth <paul@city-fan.org> - 0.34-1
- Update to 0.34:
  - Add a new spew_lines() method
  - Don't convert file into directory in subsumes()
  - Updated POD for copy_to and move_to methods
  - Stringify destination for copy_to method
  - Stringify destination for move_to method
  - Add Continuous Integration with Travis CI
  - Change bugtracker to github's
- Use %%license where possible

* Thu Dec 12 2013 Paul Howarth <paul@city-fan.org> - 0.33-1
- Update to 0.33:
  - New copy_to() and move_to() methods
  - As advised in the utime() docs, pass undef as the time for touch()
  - Do a better job cleaning up temp files in the tests
  - Optimization: use parent.pm instead of base.pm
  - Changed the docs to show that file() and dir() are exported by default
  - Fixed spelling error in POD

* Wed Sep 18 2013 Paul Howarth <paul@city-fan.org> - 0.32-3
- Don't BR: perl(Test::Perl::Critic) when bootstrapping

* Wed Jul 24 2013 Paul Howarth <paul@city-fan.org> - 0.32-2
- Perl 5.18 rebuild

* Tue Mar 19 2013 Paul Howarth <paul@city-fan.org> - 0.32-1
- Update to 0.32:
  - Updated dependency on File::Spec to 3.26 (CPAN RT#83143)
  - Fixed bug with leading empty string in dir() - became unintentional
    UNC path on Cygwin
  - Fixed "Unterminated C<...> sequence" in Pod

* Thu Mar  7 2013 Paul Howarth <paul@city-fan.org> - 0.31-1
- Update to 0.31:
  - Optimization: stringify variables passed to canonpath
  - Optimization: Use internal guts when constructing Dirs from Dirs, instead
    of concatenating and splitting them again with File::Spec
  - Fix grammar error in docs
  - Implement a 'split' parameter for the slurp() method
  - In docs, replace unicode MINUS SIGN with ascii HYPHEN-MINUS
- BR: perl(Scalar::Util)
- Bump perl(File::Spec) version requirement to 3.26 (CPAN RT#83143)
- Drop %%defattr, redundant since rpm 4.4

* Tue Dec 18 2012 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29:
  - Add components() method, which returns directory names (and filename, if
    this is a File object) as a list
  - Fix a test failure on non-Unix platforms; the 07-recurseprune.t test was
    written in a Unix-specific way

* Mon Dec 17 2012 Paul Howarth <paul@city-fan.org> - 0.28-1
- Update to 0.28:
  - Fix test failures when run as root - they were relying on permissions
    failures, but permissions never fail as root
  - Add links in docs to the other modules we rely on and talk about in the
    docs, which makes for easier viewing through search.cpan.org / MetaCPAN
  - Fixed some misleading variable names in docs (CPAN RT#81795)

* Mon Dec 10 2012 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27:
  - Added pruning support in dir->recurse(); if recurse callback returns
    $item->PRUNE, no children of this item will be analyzed
  - Documented 'basename' method for directories
  - Added traverse_if() function, which allows one to filter children before
    processing them
  - Added tempdir() function
- Package upstream LICENSE file

* Fri Jun 15 2012 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26:
  - resolve() now includes the name of the non-existent file in the error
    message
  - New shortcut opena(), to open a file for appending
  - New spew() method that does the inverse of the slurp() method
  - Fixed a typo in a class name in the docs for Path::Class::Entity
- BR: perl(Test::Perl::Critic) unconditionally
- Drop support for old distributions prior to FC-3:
  - Don't need to define %%{perl_vendorlib}

* Thu Feb 16 2012 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25:
  - resolve() now croak()s instead of die()s on non-existent file
  - Added a traverse() method for directories, based on the fmap_cont() method
    of Forest::Tree::Pure; it's an alternative to ->recurse, which allows for
    more control over how the recursion happens
  - Fixed a grammar error in the docs
- Drop upstreamed UTF-8 patch
- Add buildreqs for Perl core modules that might be dual-lived

* Fri Jul  1 2011 Paul Howarth <paul@city-fan.org> - 0.24-2
- Rebuild for perl 5.14.1 in Rawhide
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue May 31 2011 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24:
  - Added a tempfile() method for Dir objects, which provides an interface to
    File::Temp (CPAN RT#60485)
  - Fixed a non-helpful fatal error message when calling resolve() on a path
    that doesn't exist; now dies with the proper "No such file or directory"
    message and exit status
- BR: perl(Test::Perl::Critic) and run author tests where possible

* Wed Apr 13 2011 Paul Howarth <paul@city-fan.org> - 0.23-1
- Import from Fedora
- Update to 0.23:
  - slurp() now accepts an 'iomode' option to control how the file is opened
  - In the openr() and openw() file methods, we now croak() instead of die()
    so that the error messages are more useful
  - Allow subclassing, by adding dir_class() and file_class() static methods,
    allowing them to be overridden
  - Fixed a testing failure that could occur whenever testing in a directory
    path that contains symlinks (e.g. /tmp on Mac OS X)
  - Added a 'no_hidden' parameter for children()
  - Fixed the heading for the is_relative() POD section
  - Don't test the 'iomode' option under 5.6, because layers aren't supported
  - Fixes for spelling errors in the documentation
  - Added a basename() method for directory objects
  - Fixed a bunch of problems with the distribution (e.g. in META.yml) that
    were introduced in the switch to Dist::Zilla

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.18-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Tue Dec 21 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.18-3
- Rebuild to fix problems with vendorarch/lib (#661697)

* Tue May 04 2010 Marcela Maslanova <mmaslano@redhat.com> - 0.18-2
- Mass rebuild with perl-5.12.0

* Mon Feb 22 2010 Chris Weyl <cweyl@alumni.drew.edu> - 0.18-1
- Update to 0.18 (for latest DBIx::Class)

* Mon Dec  7 2009 Stepan Kasal <skasal@redhat.com> - 0.16-6
- Rebuild against perl 5.10.1

* Sun Jul 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.16-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Thu Feb 26 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.16-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Mar  5 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 0.16-3
- Rebuild for new perl

* Thu Aug 16 2007 Ian Burrell <ianburrell@gmail.com> - 0.16-2
- Fix BuildRequires

* Mon Jan 29 2007 Ian Burrell <ianburrell@gmail.com> - 0.16-1
- Specfile autogenerated by cpanspec 1.69.1
